@@ -25,8 +25,8 @@ CW_KEY = f"{BULB_COMMAND}17"
 
 _LOGGER = logging.getLogger(__name__)
 
-from .device import ColorMode
 from .base_light import SwitchbotBaseLight
+from .device import ColorMode
 
 
 class SwitchbotBulb(SwitchbotBaseLight):
@@ -88,9 +88,9 @@ class SwitchbotBulb(SwitchbotBaseLight):
         self._update_state(result)
         return self._check_command_result(result, 1, {0x80})
 
-    def _update_state(self, result: bytes) -> None:
+    def _update_state(self, result: bytes | None) -> None:
         """Update device state."""
-        if len(result) < 10:
+        if not result or len(result) < 10:
             return
         self._state["r"] = result[3]
         self._state["g"] = result[4]
